@@ -1,7 +1,7 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -28,6 +28,7 @@ sub west    { generate( @_, theta => -270, tgroups => 0 ) }
 
 sub layout          { Spreadsheet::HTML::Presets::layout(           @_ ) }
 sub list            { Spreadsheet::HTML::Presets::List::list(       @_ ) }
+sub select          { Spreadsheet::HTML::Presets::List::select(     @_ ) }
 sub handson         { Spreadsheet::HTML::Presets::Handson::handson( @_ ) }
 sub conway          { Spreadsheet::HTML::Presets::Conway::conway(   @_ ) }
 sub calculator      { Spreadsheet::HTML::Presets::Calculator::calculator( @_ ) }
@@ -89,7 +90,7 @@ sub generate {
 
     if ($args{animate}) {
         warn "animate is deprecated, use scroll instead\n";
-        $args{scroll} = delete $args{animate};
+        $args{scroll} = $args{animate};
     }
 
     if ($args{scroll}) {
@@ -123,14 +124,14 @@ sub _process {
     }
 
     # headings is an alias for -r0
-    $args->{-r0} = delete $args->{headings} if exists $args->{headings};
+    $args->{-r0} = $args->{headings} if exists $args->{headings};
 
     # headings to index mapping (alias for some -cX)
     my %index = ();
     if ($#{ $data->[0] }) {
         %index = map { '-' . ($data->[0][$_] || '') => $_ } 0 .. $#{ $data->[0] };
         for (grep /^-/, keys %$args) {
-            $args->{"-c$index{$_}" } = delete $args->{$_} if exists $index{$_};
+            $args->{"-c$index{$_}" } = $args->{$_} if exists $index{$_};
         }
     }
 
@@ -203,7 +204,7 @@ sub _make_table {
         push @cdata, (
             ( $head ? { tag => 'thead', attr => $args{thead}, cdata => $head_row } : () ),
             ( $foot ? { tag => 'tfoot', attr => $args{tfoot}, cdata => $foot_row } : () ),
-            ( map { tag => 'tbody', attr => $args{tbody}, cdata => [ @$_ ] }, @$body_rows ),
+            ( map     { tag => 'tbody', attr => $args{tbody}, cdata => $_ }, @$body_rows ),
         );
 
 
@@ -211,7 +212,7 @@ sub _make_table {
         push @cdata, map { tag => 'tr', attr => $args{tr}, cdata => $_ }, @{ $args{data} };
     }
 
-    return $args{_auto}->tag( tag => 'table', attr => $args{table}, cdata => [ @cdata ] );
+    return $args{_auto}->tag( tag => 'table', attr => $args{table}, cdata => \@cdata );
 }
 
 sub _caption {
@@ -286,7 +287,7 @@ sub _args {
     $args = { %{ $self || {} }, %{ $args || {} } };
     $data = delete $args->{data} if exists $args->{data};
 
-    $args->{_auto} = HTML::AutoTag->new(
+    $args->{_auto} ||= HTML::AutoTag->new(
         indent  => $args->{indent},
         level   => $args->{level},
         sorted  => $args->{sorted_attrs},
@@ -840,6 +841,8 @@ with little to no additional coding.
 
 =item * C<list( ordered, col, row, %params )>
 
+=item * C<select( col, row, labels, texts, values, placeholder, label, %params )>
+
 =item * C<handson( handsonjs, jquery, css, %params )>
 
 =item * C<banner( on, off, text, font, %params )>
@@ -848,10 +851,6 @@ with little to no additional coding.
 
 =item * C<scroll( fgdirection, bgdirection, jquery, %params )>
 
-=item * C<animate( fgdirection, bgdirection, jquery, %params )>
-
-Deprecated. Use C<scroll> instead.
-
 =item * C<conway( on, off, fade, jquery, %params )>
 
 =item * C<calculator( jquery, %params )>
@@ -870,6 +869,8 @@ Deprecated. Use C<scroll> instead.
 
 =item * C<beadwork( %params )>
 
+=item * C<animate( %params )> - Deprecated: use C<scroll()> instead.
+
 =back
 
 See L<Spreadsheet::HTML::Presets> for more documentation
@@ -881,9 +882,8 @@ See L<Spreadsheet::HTML::Presets> for more documentation
 
 =item * L<HTML::AutoTag>
 
-Used to generate HTML. Handles indentation and HTML entity encoding.
-Uses L<Tie::Hash::Attribute> to handle rotation of class attributes
-and L<HTML::Entities> for encoding of CDATA.
+Used to generate HTML tags and  attributes. Handles indentation and HTML entity encoding.
+Requires L<Tie::Hash::Attribute> and L<HTML::Entities>.
 
 =back
 
@@ -904,7 +904,7 @@ different file formats:
 
 =item * L<Spreadsheet::Read>
 
-Uses the following:
+Uses the following optional modules:
 
 =over 4
 
@@ -926,8 +926,7 @@ Uses the following:
 
 =back
 
-The following are used by some presets to enhance
-their output, if installed:
+The following are used by some presets to enhance output, if installed:
 
 =over 4
 
